@@ -41,14 +41,18 @@ class BackslashTreeProcessor(Treeprocessor):
 			elif element.tag in ['ul', 'ol']:
 
 				for sub_element in element:
-					item = etree.Element('li')
-					span = etree.SubElement(item, 'span', attrib={'class': 'indent'})
-					span.tail = sub_element.text
-					elements.append(item)
-					item.tail = '\n'
+
+					if sub_element.tag == 'li':
+						item = etree.Element('li')
+						span = etree.SubElement(item, 'span', attrib={'class': 'indent'})
+						sub_element.tag = 'span'
+						sub_element.tail = ''
+						item.append(sub_element)
+						item.tail = '\n'
+						elements.append(item)
 
 				line = etree.Element('li')
-				line.tail = '\n'
+				line.tail = '\n '
 				elements.append(line)
 
 			# Code blocks
